@@ -65,6 +65,7 @@ class OrganizationModel(IdNameModel):
 class BaseOrganizationsModel(BaseResponseModel):
     organizations: List[OrganizationModel]
 
+
     def __list_id__(self):
         return [org.id for org in self.organizations]
 
@@ -698,7 +699,7 @@ class NProductModel(BaseModel):
     proteins_amount: Optional[float] = Field(alias="proteinsAmount")
     carbohydrates_amount: Optional[float] = Field(alias="energyAmount")
     energy_amount: Optional[float] = Field(alias="carbohydratesAmount")
-    fatFull_amount: Optional[float] = Field(alias="fatFullAmount")
+    fat_full_amount: Optional[float] = Field(alias="fatFullAmount")
     proteins_full_amount: Optional[float] = Field(alias="proteinsFullAmount")
     carbohydrates_full_amount: Optional[float] = Field(alias="carbohydratesFullAmount")
     energy_full_amount: Optional[float] = Field(alias="energyFullAmount")
